@@ -46,6 +46,7 @@ static GSList *connections = NULL;
 
 static gboolean _bt_down = FALSE;
 static gboolean _flight_mode = FALSE;
+static gboolean _down_before_flight = FALSE;
 static gboolean _cover_closed = FALSE;
 #ifdef USE_MCE
 static gboolean _inactive = FALSE;
@@ -226,6 +227,7 @@ gboolean bt_disabled(void)
 void mode_change(const char *mode)
 {
     if (g_str_equal(mode, "flight")) {
+        _down_before_flight = _bt_down;
         disable_bt();
         _flight_mode = TRUE;
     }
@@ -235,7 +237,8 @@ void mode_change(const char *mode)
         if (_cover_closed)
             return;
 #endif
-        enable_bt();
+        if (!_down_before_flight)
+            enable_bt();
     }
     else
         error("Invalid mode \"%s\" passed to mode_change()", mode);
